@@ -2,14 +2,14 @@ coph.tocher <-
 function(obj)
 {
    if (!inherits(obj, "tocher"))
-      stop("'obj' must be an object of class 'dist'!")
-   dc <- attr(obj, "distClust")
-   d <- attr(obj, "d")
+      stop("'obj' must be an object of class 'tocher'!")
+   dc <- obj$distClust
+   d <- obj$d
    ord <- attr(d, "Labels")
-   lab <- unlist(obj)
+   lab <- unlist(obj$clusters)
    n <- length(lab)
-   nc <- length(obj)
-   nopc <- sapply(obj, length)
+   nc <- length(obj$clusters)
+   nopc <- sapply(obj$clusters, length)
    cl <- rep(1:nc, nopc)
    coph <- matrix(0, n, n)
    dimnames(coph) <- list(lab, lab)
